@@ -4,10 +4,10 @@ package LWP::Protocol::AnyEvent::http;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('v1.10.0');
+use version; our $VERSION = qv('v1.12.0');
 
 use AnyEvent            qw( );
-use AnyEvent::HTTP      qw( http_request );
+use AnyEvent::HTTP      qw( );
 use HTTP::Response      qw( );
 use LWP::Protocol       qw( );
 use LWP::Protocol::http qw( );
@@ -133,13 +133,22 @@ sub request {
       $opts{tls_ctx} = $self->_get_tls_ctx();
    }
 
+   my $http_request = \&AnyEvent::HTTP::http_request;
+   $opts{proxy} = undef;
    if ($proxy) {
-      my $proxy_uri = URI->new($proxy);
-      $opts{proxy} = [ $proxy_uri->host, $proxy_uri->port, $proxy_uri->scheme ];
+      if ($proxy =~ /^socks/) {
+         require AnyEvent::HTTP::Socks;
+         $http_request = \&AnyEvent::HTTP::Socks::http_request;
+         $proxy =~ s{socks://}{socks5://}gi;
+         $opts{socks} = $proxy;
+      } else {
+         my $proxy_uri = URI->new($proxy);
+         $opts{proxy} = [ $proxy_uri->host, $proxy_uri->port, $proxy_uri->scheme ];
+      }
    }
 
    # Let LWP handle redirects and cookies.
-   http_request(
+   $http_request->(
       $method => $url,
       headers => \%headers,
       %opts,
@@ -203,7 +212,7 @@ LWP::Protocol::AnyEvent::http - Event loop friendly HTTP and HTTPS backend for L
 
 =head1 VERSION
 
-Version 1.10.0
+Version 1.12.0
 
 
 =head1 SYNOPSIS
@@ -288,7 +297,7 @@ Only the following C<ssl_opts> are currently supported:
 
 =item * C<SSL_verify_mode>
 
-Only partially supported. Unspecified or VERIFY_NONE disables verification, anything else enables it.
+Only partially supported. Unspecified or C<VERIFY_NONE> disables verification, anything else enables it.
 
 =item * C<SSL_verifycn_scheme>
 
@@ -313,6 +322,27 @@ As with L<LWP::Protocol::https>, if hostname verification is requested by L<LWP:
 The maintainer will be happy to add support for additional options.
 
 
+=head1 PROXY SUPPORT
+
+The following proxy types are supported:
+
+=over 4
+
+=item * C<https>
+
+=item * C<http>
+
+=item * C<socks> (alias for C<socks5>)
+
+=item * C<socks5> (requires L<AnyEvent::HTTP::Socks>)
+
+=item * C<socks4a> (requires L<AnyEvent::HTTP::Socks>)
+
+=item * C<socks4> (requires L<AnyEvent::HTTP::Socks>)
+
+=back
+
+
 =head1 SEE ALSO
 
 =over 4
@@ -341,7 +371,9 @@ in problems in some unrelated code. Doesn't support HTTPS. Supports FTP and NTTP
 
 =item * L<AnyEvent::HTTP::LWP::UserAgent>
 
-An alternative to this module. Doesn't help code that uses L<LWP::Simple> or L<LWP::UserAgent> directly.
+An alternative to this module that attempts to provide the same interface as
+L<LWP::UserAgent>, but falls short in many ways. Unlike L<AnyEvent::HTTP::LWP::UserAgent>,
+this module only replaces the back end of L<LWP::UserAgent>, offering a much more faithful experience.
 
 =back
 
